@@ -2,29 +2,21 @@
 #' 
 #' @description Convert and export meshcode area to geojson string.
 #' @param code meshcode 
-#' @import foreach
-#' @importFrom dplyr mutate
-#' @importFrom dplyr select
-#' @importFrom purrr map
-#' @importFrom purrr map_df
-#' @importFrom sp Polygons
-#' @importFrom sp SpatialPolygons
-#' @importFrom geojsonio geojson_json
-#' @return geojson character strings
+#' @importFrom dplyr mutate select
+#' @importFrom purrr map map_df
+#' @return sf
 #' @examples 
-#' # export geojson string
 #' export_mesh(
 #'   code = latlong_to_meshcode(lat = 35.82083, long = 137.0563, order = 3))
 #' 
 #' library(leaflet)
 #' leaflet() %>%
 #' addTiles() %>%
-#' setView(lng = 135.0, lat = 38.0, zoom = 3) %>%
-#' addGeoJSON(
-#'   export_mesh(
-#'     code = c(
-#'     latlong_to_meshcode(lat = 35.82083, long = 137.0563, order = 3),
-#'     latlong_to_meshcode(lat = 38.40052, long = 141.0131, order = 3))))
+#' setView(lng = 135.0, lat = 38.0, zoom = 3) %>% 
+#' addPolygons(data = export_mesh(
+#' code = c(
+#' latlong_to_meshcode(lat = 35.82083, long = 137.0563, order = 3),
+#' latlong_to_meshcode(lat = 38.40052, long = 141.0131, order = 3))))
 #' @export
 export_mesh <- function(code) {
   
@@ -44,8 +36,7 @@ export_mesh <- function(code) {
     bundle_mesh_vars() %>% 
     dplyr::select(mesh_code, lng1, lat1, lng2, lat2)
   
-  res <- poly_to_geojson(df)
-  
+  res <- poly_to_sf(df)
   return(res)
 }
 
